@@ -13,7 +13,7 @@ package Dist::Zilla::PluginBundle::Author::Celogeek;
 use strict;
 use warnings;
 
-our $VERSION = '0.4';    # VERSION
+our $VERSION = '0.5';    # VERSION
 
 use Moose;
 use Class::MOP;
@@ -22,11 +22,11 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
 
 sub before_build {
     my $self = shift;
-    unless ( -e 'xt/.perltidyrc' ) {
-        unless ( -d 'xt' ) {
-            mkdir('xt');
-        }
-        if ( open my $f, '>', 'xt/.perltidyrc' ) {
+    unless ( -d 'xt' ) {
+        mkdir('xt');
+    }
+    unless ( -e 'xt/perltidy.rc' ) {
+        if ( open my $f, '>', 'xt/perltidy.rc' ) {
             print $f <<EOF
 #Perl Best Practice Conf
 -l=78
@@ -48,6 +48,21 @@ EOF
             close $f;
         }
     }
+    unless ( -e 'xt/perlcritic.rc' ) {
+        if ( open my $f, '>', 'xt/perlcritic.rc' ) {
+            print $f <<EOF
+severity = 3
+theme = (pbp || security) && bugs
+criticism-fatal = 1
+color = 1
+
+[Subroutines::ProtectPrivateSubs]
+allow = Encode::_utf8_on
+EOF
+                ;
+        }
+    }
+    return;
 }
 
 sub configure {
@@ -85,9 +100,11 @@ sub configure {
         'MetaConfig',
         [ 'PodWeaver' => { 'config_plugin' => '@Celogeek' } ],
         [ 'Run::BeforeRelease' => { run => 'cp %d%pREADME.mkdn .' } ],
-        [ 'PerlTidy' => { 'perltidyrc' => 'xt/.perltidyrc' } ],
+        [ 'PerlTidy'           => { 'perltidyrc'    => 'xt/perltidy.rc' } ],
+        [ 'Test::Perl::Critic' => { 'critic_config' => 'xt/perlcritic.rc' } ],
     );
 
+    return;
 }
 
 1;
@@ -101,7 +118,7 @@ Dist::Zilla::PluginBundle::Author::Celogeek - Dist::Zilla like Celogeek
 
 =head1 VERSION
 
-version 0.4
+version 0.5
 
 =head1 OVERVIEW
 
@@ -141,7 +158,9 @@ This is the bundle of Celogeek, and is equivalent to create this dist.ini :
   [Run::BeforeRelease]
   run = cp %d%pREADME.mkdn .
   [PerlTidy]
-  perltidyrc = xt/.perltidyrc
+  perltidyrc = xt/perltidy.rc
+  [Test::Perl::Critic]
+  critic_config = xt/perlcritic.rc
 
 Here a simple dist.ini :
 
@@ -171,8 +190,8 @@ Here my Changes file :
 
 Here my .gitignore :
 
-    xt/.perltidyrc
-    xt/.perlcriticrc
+    xt/perltidy.rc
+    xt/perlcritic.rc
     MyTest-*
     *.swp
     *.bak
